@@ -179,7 +179,7 @@ class TestStandardRest:
                     'Must define the header schema globally or specifically in the task.'
                 )
         validate(
-            instance=self.ctx.session.headers,
+            instance=dict(self.ctx.session.headers),
             schema=schema
         )
 
